/***
 * uGASP: an OSGi middleware dedicated to ubiquitous multiplayer gaming.
 * Copyright (C) 2008 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.ugasp.impl.connector.http;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Iterator;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.ugasp.core.ActorSession;
import org.ugasp.core.ApplicationInstance;
import org.ugasp.core.MasterApplicationInstance;
import org.ugasp.core.Session;
import org.ugasp.service.external.admin.AdminConnector;

public class AdminWebPages {
	
	/**
	 * HTML uGASP state rendering
	 * 
	 * @param request
	 * @param response
	 * @param adminConnector
	 * @throws IOException
	 */
	public static void renderPlatformState(HttpServletRequest request, HttpServletResponse response, AdminConnector adminConnector) throws IOException{
		int size = adminConnector.getCore().masterApplicationInstanceSize();
		
		response.setContentType("text/html");
		PrintWriter out = response.getWriter();
		
		int numberOfUsers = 0;
		for(Iterator iter1 = adminConnector.getCore().enumerateMasterApplicationInstance();iter1.hasNext();){
			MasterApplicationInstance masterApp = (MasterApplicationInstance) iter1.next();
			numberOfUsers += masterApp.getActorsList().size();
		}
		
		out.println("<html>");
		out.println("<head><title>uGASP State HTML Viewer</title></head>");
		out.println("<body bgcolor=\"#E0E0E0 \" >");
		out.println("<font size=\"1\"face=\"Verdana\">");
		out.println("<center>");
		
		out.println("<table bgcolor=\"#8470FF\" height=\"95%\" width=\"68%\" cellspacing=10>");
		
		out.println("<tr height=\"30\">");
		out.println("<td align=\"left\" bgcolor=\"#585858 \" colspan=2>");
		out.println("<font size=\"3\" color=\"white\"><b>uGASP State HTML Viewer v1.0</b></font>");
		out.println("</td>");
		out.println("</tr>");
		
		out.println("<tr>");
		out.println("<td align= center>");
		
		out.println("<table bgcolor=\"white\" border=0  width=\"68%\" cellspacing=0>");
		out.println("<th bgcolor=\"#FFCC33\" colspan=2>");
		out.println("<font size=\"2\" color=\"blue\">Platform</font>");
		out.println("</th>");
		
		out.println("<td align=\"left\">");
		out.println("<font size=\"2\">DB connection</font>");
		out.println("</td>");
		out.println("<td align=\"right\">");
		out.println("<font size=\"2\">"+(adminConnector.getDBManager().isDBConnectionOK() ? "ok" : "nok see logs")+"</font>");
		out.println("</td>");
		out.println("</tr>");
		
		out.println("<tr>");
		out.println("<td align=\"left\">");
		out.println("<font size=\"2\">Platform timeout</font>");
		out.println("</td>");
		out.println("<td align=\"right\">");
		out.println("<font size=\"2\">"+(adminConnector.getCore().getPlatformTimeout())+"</font>");
		out.println("</td>");
		out.println("</tr>");
		out.println("<tr>");
		
		out.println("<tr>");
		out.println("<td align=\"left\">");
		out.println("<font size=\"2\">Current number of Master Applications</font>");
		out.println("</td>");
		out.println("<td align=\"right\">");
		out.println("<font size=\"2\">"+size+"</font>");
		out.println("</td>");
		out.println("</tr>");
		
		out.println("<tr>");
		out.println("<td align=\"left\">");
		out.println("<font size=\"2\">Current total number of Users</font>");
		out.println("</td>");
		out.println("<td align=\"right\">");
		out.println("<font size=\"2\">"+numberOfUsers+"</font>");
		out.println("</td>");
		out.println("</tr>");
		
		out.println("</table>");
		
		out.println("</td>");
		out.println("</tr>");
		
		for(Iterator iter1 = adminConnector.getCore().enumerateMasterApplicationInstance();iter1.hasNext();){
			MasterApplicationInstance masterApp = (MasterApplicationInstance) iter1.next();
			
			out.println("<tr>");
			out.println("<td align= center>");
			
			out.println("<table bgcolor=\"white\" border=0 width=\"68%\" cellspacing=0>");
			out.println("<th bgcolor=\"#FFCC33\" colspan=2>");
			out.println("<font size=\"2\" color=\"blue\">Master Application Instance</font>");
			out.println("</th>");
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">MAID</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+masterApp.getMasterApplicationID()+"</font>");
			out.println("</td>");
			out.println("</tr>");
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Application ID</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+masterApp.getApplicationID()+"</font>");
			out.println("</td>");
			out.println("</tr>");
			
			String model;
			switch (masterApp.getApplicationModel()){
				case 0: 
				    model="auto";
				    break;
				case 1:
				    model="manual";
				    break;
				case 2:
				    model="mapcycle";
				default: 
				    model="unknow";
				    break;
			}
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Application Model</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+model+"</font>");
			out.println("</td>");
			out.println("</tr>");
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Application timeout</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+masterApp.getApplicationTimeout()+"</font>");
			out.println("</td>");
			out.println("</tr>");
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Number of Application Instances</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+masterApp.getApplicationInstancesList().size()+"</font>");
			out.println("</td>");
			out.println("</tr>");

			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Number of Users</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			out.println("<font size=\"2\">"+masterApp.getActorsList().size()+"</font>");
			out.println("</td>");
			out.println("</tr>");
			
			out.println("<tr>");
			out.println("<td align=\"left\">");
			out.println("<font size=\"2\">Users IDs infos (aID/sID)</font>");
			out.println("</td>");
			out.println("<td align=\"right\">");
			for(Session session : masterApp.getSessionsList()){
				out.println("<font size=\"2\">"+"("+session.getActorID()+"/"+session.getSessionID()+")"+"</font>");
			}
			out.println("</td>");
			out.println("</tr>");
			
			
			for(ApplicationInstance applicationInstance : masterApp.getApplicationInstancesList()){
			    out.println("<tr>");
			    out.println("<td align=\"left\" bgcolor=\"#FFCC33\" colspan=2>");
				out.println("<font size=\"2\" color=\"blue\"> <b> Application Instance </b></font>");
				out.println("</td>");
				out.println("</tr>");
			    out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">AIID</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				out.println("<font size=\"2\">"+applicationInstance.getApplicationInstanceID()+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">Number of players</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				out.println("<font size=\"2\">"+applicationInstance.getActorSessionsList().size()+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">Owner ASID</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				out.println("<font size=\"2\">"+applicationInstance.getOwnerActorSessionID()+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">Minimum starting number of players</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				out.println("<font size=\"2\">"+applicationInstance.getMinActors()+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">Maximum number of players</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				out.println("<font size=\"2\">"+applicationInstance.getMaxActors()+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				out.println("<tr>");
				out.println("<td align=\"left\">");
				out.println("<font size=\"2\">Status</font>");
				out.println("</td>");
				out.println("<td align=\"right\">");
				
				String status;
				if (applicationInstance.isDestroyable()) status = "[Destroy Mode]";
				else if (applicationInstance.isRunning()){
				    status = "[In Game]";
				    if (applicationInstance.isJoinable()) status+="[full:n]";
				    else status+="[full:y]";
				}
				else{
				    status = "[Waiting Room]";
				    if (applicationInstance.isJoinable()) status+="[full:n]";
				    else status+="[full:y]";
				    if (applicationInstance.getActorSessionsList().size()< applicationInstance.getMinActors()) status+= " [startable: n]";
				    else status += " [startable: y]";
				}
				
				out.println("<font size=\"2\">"+status+"</font>");
				out.println("</td>");
				out.println("</tr>");
				
				boolean first = true;
				for (ActorSession actorSession : applicationInstance.getActorSessionsList()) {
					out.println("<tr>");
					out.println("<td align=\"left\">");
					if (first){
					    out.println("<font size=\"2\">Player (aID/sID/aSID)</font>");
					    first = false;
					}else{
						out.println("<font size=\"2\">Player</font>");
					}
					out.println("</td>");
					out.println("<td align=\"right\">");
					out.println("<font size=\"2\">"+actorSession.getPseudoName());
					out.print(" ("+actorSession.getActorID()+"/"+actorSession.getSessionID()+"/"+actorSession.getActorSessionID()+") "+"</font>");
					out.println("</td>");
					out.println("</tr>");
					out.println();
				}
			}
			
			out.println("</table>");
			
		}
		
		out.println("<tr height=\"30\">");
		out.println("<td align=\"right\" bgcolor=\"#585858\" colspan=2>");
		out.println("<font size=\"2\" color=\"white\"><b>uGASP/GASP Project - http://gasp.objectweb.org - 2004/2008</b></font>");
		out.println("</td>");
		out.println("</tr>");
		
		out.println("</table>");
		out.println("</center>");
		out.println("</font>");
		out.println("</body>");
		out.println("</html>");
		out.close();
	}
}
