/***
 * uGASP: an OSGi middleware dedicated to ubiquitous multiplayer gaming.
 * Copyright (C) 2008 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.ugasp.service.external.player;

import java.io.DataInputStream;
import java.io.DataOutputStream;

public interface PlayerConnector {
    
	/**
	 * @param sid
	 * @param minActors
	 * @param maxActors
	 * @param actors
	 * @return the actorSessionID of the player
	 */
	short create(short sid, int minActors, int maxActors, String[] actors);

	/**
	 * @param asid
	 */
	void end(short asid);

	/**
	 * @param uid
	 * @param appID
	 * @param username
	 * @param password
	 * @return
	 */
	int firstLogin(short uid, short appID, String username,
			String password);


	/**
	 * @param asid
	 * @param dos
	 */
	void getEvents(DataOutputStream dos, short asid);
	
	
	/**
	 * Invoke asynchronously a remote method on a uGASP Peer (server or client).
	 * Only void method can be called this way. However, a peer which has been invoked can reply using with another call to this method.
	 * (See the August version of uGASP tutorial --> not published yet)
	 * 
	 * @param senderActorSessionID		actorSessionID of the sender
	 * @param recipientActorSessionID	actorSessionID of the recipient
	 * @param paramsXMLRepresentation	String containing xml representation of method signature (method name + params + values)
	 */
	void remoteMethodAsynchronousInvocation(short senderActorSessionID, short recipientActorSessionID, String invokedMethodXMLSerialized);
	
	
	void sendMooDSObject(DataInputStream dis, short actorSessionID);
	
	
	/**
	 * @param sid
	 * @param aiid
	 * @return
	 */
	short joinAI(short sid, short aiid);

	
	/**
	 * @param sid
	 * @param dos
	 */
	void lobby(short sid, DataOutputStream dos);

	/**
	 * @param aid
	 * @param username
	 * @param password
	 * @return
	 */
	int login(short aid, String username, String password);

	/**
	 * @param asid
	 * @param name
	 * @return
	 */
	String name(short asid, String name);

	/**
	 * @param parseInt
	 */
	void quit(int sid);

	/**
	 * @param asid
	 */
	void quitAI(short asid);

	/**
	 * @param asid
	 */
	boolean start(short asid);
	
	
	public String lobby(short sessionID);
}
