package org.ugasp.protocol.rmai;


/**
 * This class holds the methods that will be invoked remotely by other clients.
 * 
 * Declare methods respecting following properties:
 * <ul>
 * <li>they must be instances methods, and not static ones</li>
 * <li>types handled as parameters are Byte, Short, Integer, Long, Float, Double, Boolean, String, RMAISerializable and arrays of all those types</li>
 * <li>as method invocations through RMAI protocol are asynchronous,
 * only void methods can be invoked. However a callback mechanism is provided, allowing to invoke remote method
 * on the entity which did the invocation first.</li>
 * </ul>
 * 
 * Entity which has invoked a method located in this class can be retrieved, using getSenderActorSessionID().
 **/
public class RMAIGameLogicManager{

	protected short senderActorSessionID;
	protected short recipientActorSessionID;
	
	public RMAIGameLogicManager(short senderActorSessionID, short recipientActorSessionID){
		this.senderActorSessionID = senderActorSessionID;
		this.recipientActorSessionID = recipientActorSessionID;
	}
	
	public short getSenderActorSessionID() {
		return senderActorSessionID;
	}
	
	public short getRecipientActorSessionID() {
		return recipientActorSessionID;
	}
	
	
	/** 
	 * This class is used to broadcast remote procedures asynchronous invocations.
	 * If you want to do so, in the several GameLogic.remoteMethodAsynchronousInvocation(int recipientActorSessionID,String methodName,Object param0,...),
	 * you should use whether:
	 * <ul>
	 * <li>ActorSessionID.BROADCAST_WITHOUT_GAME_LOGIC.getID(), or</li> 
	 * <li>ActorSessionID.BROADCAST_WITH_GAME_LOGIC.getID()</li>
	 * </ul>
	 * as the recipientActorSessionID.
	 * If you just want to invoke a method on one client, simply use its actor session ID (the short value). 
	 */
	public static class ActorSessionID{

		
		private final short id;

		
		private ActorSessionID(short id){
			this.id = id;
		}

		
		public short getID(){return id;}
		public final static ActorSessionID uGASP_GAME_LOGIC = new ActorSessionID((short)0);
		public final static ActorSessionID BROADCAST_WITHOUT_GAME_LOGIC = new ActorSessionID((short)-1);
		public final static ActorSessionID BROADCAST_WITH_GAME_LOGIC = new ActorSessionID((short)-2);
		
		
		public String toString(){
			// for uGASP game logic
			if(id == uGASP_GAME_LOGIC.getID())return "uGASP_GAME_LOGIC";
			// for broadcast to clients
			else if(id == BROADCAST_WITHOUT_GAME_LOGIC.getID())return "BROADCAST_WITHOUT_GAME_LOGIC";
			// for broadcast to clients and server
			else if(id == BROADCAST_WITH_GAME_LOGIC.getID())return "BROADCAST_WITH_GAME_LOGIC";
			// otherwise 
			else return "INCORRECT_ACTOR_SESSION_ID";
		}

	}
}
